# simple-search-engine

A search engine implementation written in pure Python. This project has peeled off of [Stefan's Blog](https://github.com/Stefan4472/Stefans-Blog). Calling it "stefansearch" is not an act of vanity--I wanted to call this library "simplesearch", but that name was unfortunately taken on the Python Package Index :(

For testing, this project uses the works of William Shakespeare, sourced from Project Guthenberg (https://www.gutenberg.org/ebooks/100).